@@ -644,10 +644,11 @@ class GPF:
         Lines=[]
         try:
             for Line in In:
-                Lines.append(Line.strip())
-                No+=1
-                if No >10:
-                    break
+                if len(Line) > 20:
+                    Lines.append(Line.strip())
+                    No+=1
+                    if No >10:
+                        break
         except:
             print("",end="")
         In.close()
@@ -679,7 +680,7 @@ class GPF:
                Num2+=1
             Len+=len(Word)
         AvgLen=int(Len/len(AllWords))
-        if Num1 == len(AllWords):
+        if Num1 > int(len(AllWords)*0.9):
             return False
 
         if AvgLen <= 4:
@@ -698,6 +699,9 @@ class GPF:
         Ret=""
         for Line in In:
             Line=Line.strip()
+            if Cmd == "Convert":
+                print(Line,file=Out)
+                continue
             Sent=Line.split("。")
             for s in  Sent:
                 s=s[0:512]
@@ -721,12 +725,20 @@ class GPF:
                 print("{}{}".format(FileTmp,No),file=OutList)
                 No+=1
             else:
-                print(File,file=OutList)
+                encoding = detect_file_encoding(File)
+                if encoding != 'gbk':
+                    FileTmp=os.path.join(self.dataPath,os.path.basename(File))
+                    self.ProcessFile(File,"{}{}".format(FileTmp,No),"Convert")
+                    print("{}{}".format(FileTmp,No),file=OutList)
+                    No+=1
+                else:
+                    print(File,file=OutList)
         OutList.close()
         InList.close()
 
     def Corpus(self,PathIn,filelistNames):
         for File in os.listdir(PathIn):
+            print(File)
             AbsFile = os.path.join(PathIn, File)
             if os.path.isdir(AbsFile):
                 self.Corpus(AbsFile,filelistNames)
@@ -761,7 +773,7 @@ class GPF:
         else:
             Out=open(filelist,"w")
             for File in filelistname:
-                print(File,file=Out)    
+                print(File,file=Out)
             Out.close()
         filelistEx=os.path.join(self.dataPath,"indexlistEx.tmp")
         self.File2Corpus(filelist,filelistEx,Param[0])
